/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","hu",{abort:"A feltöltést a felhasználó megszakította.",doneOne:"A fájl sikeresen feltöltve.",doneMany:"%1 fájl sikeresen feltöltve.",uploadOne:"Fájl feltöltése ({percentage}%)...",uploadMany:"Fájlok feltöltése, {current}/{max} kész ({percentage}%)..."});