/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("filetools","zh",{loadError:"在讀取檔案時發生錯誤。",networkError:"在上傳檔案時發生網路錯誤。",httpError404:"在上傳檔案時發生 HTTP 錯誤（404：檔案找不到）。",httpError403:"在上傳檔案時發生 HTTP 錯誤（403：禁止）。",httpError:"在上傳檔案時發生 HTTP 錯誤（錯誤狀態：%1）。",noUrlError:"上傳的 URL 未被定義。",responseError:"不正確的伺服器回應。"});