CKEDITOR.plugins.setLang("docprops","nl",{bgColor:"Achtergrondkleur",bgFixed:"Niet-scrollend (gefixeerde) achtergrond",bgImage:"Achtergrondafbeelding URL",charset:"Tekencodering",charsetASCII:"ASCII",charsetCE:"Centraal Europees",charsetCR:"Cyrillisch",charsetCT:"Traditioneel Chinees (Big5)",charsetGR:"Grieks",charsetJP:"Japans",charsetKR:"Koreaans",charsetOther:"Andere tekencodering",charsetTR:"Turks",charsetUN:"Unicode (UTF-8)",charsetWE:"West Europees",chooseColor:"Kies",design:"Ontwerp",docTitle:"Paginatitel",
docType:"Documenttype-definitie",docTypeOther:"Andere documenttype-definitie",label:"Documenteigenschappen",margin:"Pagina marges",marginBottom:"Onder",marginLeft:"Links",marginRight:"Rechts",marginTop:"Boven",meta:"Meta tags",metaAuthor:"Auteur",metaCopyright:"Auteursrechten",metaDescription:"Documentbeschrijving",metaKeywords:"Trefwoorden voor indexering (komma-gescheiden)",other:"Anders...",previewHtml:'<p>Dit is <strong>voorbeeld tekst</strong>. Je gebruikt <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"Documenteigenschappen",txtColor:"Tekstkleur",xhtmlDec:"XHTML declaratie invoegen"});