/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","tr",{abort:"Gönderme işlemi kullanıcı tarafından durduruldu.",doneOne:"Gönderim işlemi başarılı şekilde tamamlandı.",doneMany:"%1 dosya başarılı şekilde gönderildi.",uploadOne:"Dosyanın ({percentage}%) gönderildi...",uploadMany:"Toplam {current} / {max} dosyanın ({percentage}%) gönderildi..."});