/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","nl",{abort:"Upload gestopt door de gebruiker.",doneOne:"Bestand succesvol geüpload.",doneMany:"Succesvol %1 bestanden geüpload.",uploadOne:"Uploaden bestand ({percentage}%)…",uploadMany:"Bestanden aan het uploaden, {current} van {max} klaar ({percentage}%)…"});