/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","pl",{abort:"Wysyłanie przerwane przez użytkownika.",doneOne:"Plik został pomyślnie wysłany.",doneMany:"Pomyślnie wysłane pliki: %1.",uploadOne:"Wysyłanie pliku ({percentage}%)...",uploadMany:"Wysyłanie plików, gotowe {current} z {max} ({percentage}%)..."});