/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","fr",{abort:"Téléversement interrompu par l'utilisateur.",doneOne:"Fichier téléversé avec succès.",doneMany:"%1 fichiers téléversés avec succès.",uploadOne:"Téléversement du fichier en cours ({percentage}%)...",uploadMany:"Téléversement des fichiers en cours, {current} sur {max} effectués ({percentage}%)..."});