CKEDITOR.plugins.setLang("docprops","he",{bgColor:"צבע רקע",bgFixed:"רקע לא נגלל (צמוד)",bgImage:"כתובת של תמונת רקע",charset:"קידוד תווים",charsetASCII:"ASCII",charsetCE:"מרכז אירופאי",charsetCR:"קירילי",charsetCT:"סיני מסורתי (Big5)",charsetGR:"יווני",charsetJP:"יפני",charsetKR:"קוריאני",charsetOther:"קידוד תווים אחר",charsetTR:"טורקי",charsetUN:"יוניקוד (UTF-8)",charsetWE:"מערב אירופאי",chooseColor:"בחירה",design:"עיצוב",docTitle:"כותרת עמוד",docType:"כותר סוג מסמך",docTypeOther:"כותר סוג מסמך אחר",
label:"מאפייני מסמך",margin:"מרווחי עמוד",marginBottom:"תחתון",marginLeft:"שמאלי",marginRight:"ימני",marginTop:"עליון",meta:"תגי Meta",metaAuthor:"מחבר/ת",metaCopyright:"זכויות יוצרים",metaDescription:"תיאור המסמך",metaKeywords:"מילות מפתח של המסמך (מופרדות בפסיק)",other:"אחר...",previewHtml:'<p>זהו <strong>טקסט הדגמה</strong>. את/ה משתמש/ת ב<a href="javascript:void(0)">CKEditor</a>.</p>',title:"מאפייני מסמך",txtColor:"צבע טקסט",xhtmlDec:"כלול הכרזות XHTML"});