CKEDITOR.plugins.setLang("embedbase","gl",{pathName:"obxecto multimedia",title:"Multimedia integrado",button:"Inserir un  multimedia integrado",unsupportedUrlGiven:"O URL especificado non está admitido.",unsupportedUrl:"O URL {url} non está admitido polo multimedia integrado.",fetchingFailedGiven:"Non foi posíbel obter o contido do URL indicado.",fetchingFailed:"Non foi posíbel obter o contido der {url}.",fetchingOne:"Obtendo a resposta oEmbed...",fetchingMany:"Obtendo as respostas oEmbed, feito {current} de {max}..."});