/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("codesnippet","ro",{button:"Adaugă segment de cod",codeContents:"Conținutul codului",emptySnippetError:"Un segment de cod nu poate fi gol.",language:"Limba",title:"Segment de cod",pathName:"segment de cod"});