CKEDITOR.plugins.setLang("embedbase","sv",{pathName:"mediaobjekt",title:"Media Embed",button:"Insert Media Embed",unsupportedUrlGiven:"Den angivna URL:en stöds inte.",unsupportedUrl:"The URL {url} is not supported by Media Embed.",fetchingFailedGiven:"Lyckades inte hämta innehållet från den angivna URL:en.",fetchingFailed:"Lyckades inte hämta innehåll från {url}.",fetchingOne:"Hämtar oEmbed-svar...",fetchingMany:"Hämtar oEmbed-svar, {current} av {max} färdiga..."});