CKEDITOR.plugins.setLang("mathjax","sk",{title:"Matematika v TeX",button:"Matika",dialogInput:"Napíšte svoj TeX sem",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"Dokumentácia TeX",loading:"načítavanie...",pathName:"matika"});