CKEDITOR.plugins.setLang("docprops","uk",{bgColor:"Колір тла",bgFixed:"Тло без прокрутки",bgImage:"URL зображення тла",charset:"Кодування набору символів",charsetASCII:"ASCII",charsetCE:"Центрально-європейська",charsetCR:"Кирилиця",charsetCT:"Китайська традиційна (Big5)",charsetGR:"Грецька",charsetJP:"Японська",charsetKR:"Корейська",charsetOther:"Інше кодування набору символів",charsetTR:"Турецька",charsetUN:"Юнікод (UTF-8)",charsetWE:"Західно-европейская",chooseColor:"Обрати",design:"Дизайн",docTitle:"Заголовок сторінки",
docType:"Заголовок типу документу",docTypeOther:"Інший заголовок типу документу",label:"Властивості документа",margin:"Відступи сторінки",marginBottom:"Нижній",marginLeft:"Лівий",marginRight:"Правий",marginTop:"Верхній",meta:"Мета дані",metaAuthor:"Автор",metaCopyright:"Авторські права",metaDescription:"Опис документа",metaKeywords:"Ключові слова документа (розділені комами)",other:"<інший>",previewHtml:'<p>Це приклад<strong>тексту</strong>. Ви використовуєте<a href="javascript:void(0)"> CKEditor </a>.</p>',
title:"Властивості документа",txtColor:"Колір тексту",xhtmlDec:"Ввімкнути XHTML оголошення"});